@@ -1,5 +1,5 @@
 package Beam::Minion::Util;
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 # ABSTRACT: Utility functions for Beam::Minion
 
 #pod =head1 SYNOPSIS
@@ -67,7 +67,11 @@ sub minion_init_args {
         unless $ENV{BEAM_MINION};
     my ( $backend, $url );
     if ( $ENV{BEAM_MINION} =~ /^[^+:]+\+/ ) {
-        return split /\+/, $ENV{BEAM_MINION};
+        my @args = split /\+/, $ENV{BEAM_MINION};
+        if ( @args == 2 ) {
+            return @args;
+        }
+        return $args[0], [ @args[1..$#args] ];
     }
     my ( $schema ) = $ENV{BEAM_MINION} =~ /^([^:]+)/;
     return $BACKEND{ $schema }, $ENV{BEAM_MINION};
@@ -99,7 +103,7 @@ Beam::Minion::Util - Utility functions for Beam::Minion
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
